# Generated by Django 4.0.6 on 2022-08-18 10:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('idp_user', '0004_auto_20220817_1526'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userrole',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
